@@ -5,8 +5,16 @@ from unipipeline.worker.uni_worker_consumer_message import UniWorkerConsumerMess
 from ul_api_utils.modules.worker_context import WorkerContext
 from ul_api_utils.modules.worker_sdk import WorkerSdk
 from ul_api_utils.modules.worker_sdk_config import WorkerSdkConfig
+from ul_api_utils.resources.socketio import SocketIOConfig, SocketIOConfigType
 
-initialized_worker = WorkerSdk(WorkerSdkConfig())
+initialized_worker = WorkerSdk(WorkerSdkConfig(
+    socket_config=SocketIOConfig(
+        app_type=SocketIOConfigType.EXTERNAL_PROCESS,
+        message_queue='redis://localhost:16379',
+        logs_enabled=True,
+        engineio_logs_enabled=False,
+    ),
+))
 
 
 class Msg(UniMessage):
