@@ -28,6 +28,7 @@ class CmdStart(Cmd):
     max_requests_jitter: int
     worker_class: str
     statsd_endpoint: Optional[str]
+    statsd_prefix: Optional[str]
 
     @property
     def app_rel_dir(self) -> str:
@@ -54,6 +55,7 @@ class CmdStart(Cmd):
         parser.add_argument('--max-requests-jitter', dest='max_requests_jitter', type=int, default=50, required=False)
         parser.add_argument('--worker-class', dest='worker_class', type=str, default='sync', required=False)
         parser.add_argument('--statsd_endpoint', dest='statsd_endpoint', type=str, default=None, required=False)
+        parser.add_argument('--statsd_prefix', dest='statsd_prefix', type=str, default=None, required=False)
 
     def run(self) -> None:
         env = os.environ.copy()
@@ -89,7 +91,10 @@ class CmdStart(Cmd):
         ]
 
         if self.statsd_endpoint and self.env != ENV_LOCAL:
-            args.extend([f'--statsd-host={self.statsd_endpoint}', f"--statsd-prefix={self.app_module.split('.')[1]}:{self.env}"])
+            if self.statsd_prefix:
+                args.extend([f'--statsd-host={self.statsd_endpoint}', f"--statsd-prefix={self.statsd_prefix}"])
+            else:
+                args.extend([f'--statsd-host={self.statsd_endpoint}', f"--statsd-prefix={self.app_module.split('.')[1]}_{self.env}"])
 
         write_stdout(f'name={name}')
         write_stdout(f'args={args}')
