@@ -8,7 +8,6 @@ from base64 import b64decode
 from datetime import datetime
 from functools import wraps
 from typing import List, Union, Callable, Tuple, Any, Optional, TypeVar, cast, Set, TYPE_CHECKING
-from ul_api_utils.resources.sockets import socket_io
 from flask import Response, request, Flask, url_for as flask_url_for, _app_ctx_stack
 from pydantic import BaseModel
 from redis.connection import parse_url
@@ -27,7 +26,7 @@ from ul_api_utils.debug import stat
 from ul_api_utils.debug.debugger import Debugger
 from ul_api_utils.errors import UserAbstractApiError, ResourceRuntimeApiError, ResponseTypeRuntimeApiError
 from ul_api_utils.internal_api.internal_api_check_context import internal_api_check_context
-from ul_api_utils.modules.api_sdk_config import ApiSdkConfig, SocketAsyncModesEnum
+from ul_api_utils.modules.api_sdk_config import ApiSdkConfig
 from ul_api_utils.modules.intermediate_state import try_init, try_configure
 from ul_api_utils.resources.caching import ULCache, TCacheMode, ULCacheMode, ULCacheConfig
 from ul_api_utils.resources.debugger_scripts import load_debugger_static_scripts
@@ -36,6 +35,7 @@ from ul_api_utils.resources.health_check.resource import init_health_check_resou
 from ul_api_utils.resources.not_implemented import not_implemented_handler
 from ul_api_utils.resources.permissions import load_permissions
 from ul_api_utils.resources.rate_limitter import init_rate_limiter
+from ul_api_utils.resources.socketio import init_socket_io, SocketAsyncModesEnum, SocketIOConfigType
 from ul_api_utils.resources.swagger import load_swagger, ApiSdkResource
 from ul_api_utils.sentry import sentry
 from ul_api_utils.utils.api_encoding import ApiEncoding
@@ -45,11 +45,12 @@ from ul_api_utils.utils.cached_per_request import cached_per_request
 from ul_api_utils.utils.constants import TKwargs
 from ul_api_utils.utils.jinja.t_url_for import t_url_for
 from ul_api_utils.utils.jinja.to_pretty_json import to_pretty_json
-from ul_api_utils.utils.json_encoder import CustomJSONEncoder
+from ul_api_utils.utils.json_encoder import CustomJSONEncoder, SocketIOJsonWrapper
 from ul_api_utils.utils.load_modules import load_modules_by_template
 from ul_api_utils.utils.uuid_converter import UUID4Converter
 
 if TYPE_CHECKING:
+    import flask_socketio  # type: ignore # lib without mypy stubs
     import flask_sqlalchemy
     from flask_mongoengine import MongoEngine      # type: ignore # lib without mypy stubs
     from ul_db_utils.modules.postgres_modules.db import DbConfig
@@ -105,6 +106,7 @@ class ApiSdk:
         '_templates_dir',
         '_fn_registry',
         '_flask_app_cache',
+        '_sio',
         '_limiter_enabled',
         '_cache',
         '_db',
@@ -120,7 +122,7 @@ class ApiSdk:
         self._flask_app_cache: Optional[Flask] = None
         self._limiter_enabled = False
         self._cache = None
-
+        self._sio: Optional['flask_socketio.SocketIO'] = None
         self._templates_dir = os.path.join(APPLICATION_DIR, 'templates')
 
         self._fn_registry: List[ApiSdkResource] = []
@@ -130,8 +132,14 @@ class ApiSdk:
     def config(self) -> ApiSdkConfig:
         return self._config
 
+    @property
+    def socket(self) -> 'flask_socketio.SocketIO':
+        assert self._sio is not None, "SocketIO is not configured, try adding SocketIOConfig to your ApiSdk first."
+        return self._sio
+
     def init_with_flask(self, app_name: str, *, db_config: Optional['MongoDbConfig'] | Optional['DbConfig'] = None) -> Flask:
         self._initialized_flask_name = try_init(self, app_name)
+        self._sio = init_socket_io(config=self._config.socket_config)
 
         if db_config is not None and type(db_config).__name__ == 'MongoDbConfig':
             from ul_db_utils.utils.waiting_for_mongo import waiting_for_mongo
@@ -199,17 +207,6 @@ class ApiSdk:
 
         load_swagger(self, self._fn_registry, self._config.api_route_path_prefix)
 
-        if self.config.sockets_config:
-            socket_io.init_app(
-                self._flask_app,
-                message_queue=self.config.sockets_config.message_queue,
-                async_mode=SocketAsyncModesEnum.GEVENT.value,
-                channel=self.config.sockets_config.channel,
-                cors_allowed_origins=self.config.sockets_config.cors_allowed_origins,
-                logger=self.config.sockets_config.logs_enabled,
-                engineio_logger=self.config.sockets_config.engineio_logs_enabled,
-            )
-
         return self._flask_app
 
     @property
@@ -257,6 +254,20 @@ class ApiSdk:
             debugger_enabled=self._debugger_enabled_with_pin,
         ))
 
+        if self._config.socket_config and self._config.socket_config.app_type is SocketIOConfigType.SERVER:
+            assert self._sio  # mypy
+            self._sio.init_app(
+                flask_app,
+                json=SocketIOJsonWrapper,
+                message_queue=self._config.socket_config.message_queue,
+                async_mode=SocketAsyncModesEnum.GEVENT.value,
+                channel=self._config.socket_config.channel,
+                cors_allowed_origins=self._config.socket_config.cors_allowed_origins,
+                logger=self._config.socket_config.logs_enabled,
+                engineio_logger=self._config.socket_config.engineio_logs_enabled,
+            )
+            load_modules_by_template([os.path.join(APPLICATION_DIR, 'sockets', '*')])
+
         return flask_app
 
     @property
