@@ -12,9 +12,11 @@ from ul_api_utils.conf import APPLICATION_START_DT
 from ul_api_utils.modules.intermediate_state import try_init, try_configure
 from ul_api_utils.modules.worker_context import WorkerContext
 from ul_api_utils.modules.worker_sdk_config import WorkerSdkConfig
+from ul_api_utils.resources.socketio import init_socket_io
 from ul_api_utils.sentry import sentry
 
 if TYPE_CHECKING:
+    import flask_socketio  # type: ignore # lib without mypy stubs
     from ul_db_utils.modules.postgres_modules.db import DbConfig
 
 TI = TypeVar('TI', bound=UniMessage)
@@ -27,6 +29,7 @@ class WorkerSdk:
         '_config',
         '_db_initialized',
         '_flask_app_cache',
+        '_sio',
     )
 
     def __init__(self, config: WorkerSdkConfig) -> None:
@@ -35,6 +38,12 @@ class WorkerSdk:
         self._config = config
         self._db_initialized = False
         self._flask_app_cache: Optional[Flask] = None
+        self._sio: Optional['flask_socketio.SocketIO'] = None
+
+    @property
+    def socket(self) -> 'flask_socketio.SocketIO':
+        assert self._sio is not None, "SocketIO client is not configured, try adding SocketIOConfig to your WorkerSdk first."
+        return self._sio
 
     @property
     def _flask_app(self) -> Flask:
@@ -50,7 +59,7 @@ class WorkerSdk:
 
     def init(self, app_name: str, *, db_config: Optional['DbConfig'] = None) -> 'WorkerSdk':
         self._initialized_flask_name = try_init(self, app_name)
-
+        self._sio = init_socket_io(config=self._config.socket_config)
         if db_config is not None:
             from ul_db_utils.utils.waiting_for_postgres import waiting_for_postgres
             self._db_initialized = True
