@@ -378,6 +378,7 @@ class SwaggerQueryParameter(SwaggerModel):
         name: Optional[str] = None,
         description: Optional[str] = None,
         required: bool = True,
+        enum: Optional[list] = None,  # type: ignore
     ) -> None:
         super(SwaggerQueryParameter, self).__init__()
         self.input_type = InputType.from_string(input_type)  # type: ignore
@@ -386,6 +387,7 @@ class SwaggerQueryParameter(SwaggerModel):
         self.name = name
         self.description = f'description: {description}' if description else ''
         self.required = required
+        self.enum = enum
 
     def perform_write(self, file) -> None:  # type: ignore
         if self.input_type.value == InputType.UUID:
@@ -407,25 +409,48 @@ class SwaggerQueryParameter(SwaggerModel):
                 ),
             )
         else:
-            parameter_entry = inspect.cleandoc(
-                """
-                    - in: query
-                      name: {name}
-                      schema:
-                        type: {input_type}
-                        {input_format}
-                      {default_value}
-                      {description}
-                      required: {required}
-                """.format(
-                    name=self.name,
-                    required=self.required,
-                    description=self.description,
-                    input_type=self.input_type.value,
-                    input_format=self.input_format,
-                    default_value=self.default_value,
-                ),
-            )
+            if self.enum is not None:
+                parameter_entry = inspect.cleandoc(
+                    """
+                        - in: query
+                          name: {name}
+                          schema:
+                            type: {input_type}
+                            {input_format}
+                            enum: {enum}
+                          {default_value}
+                          {description}
+                          required: {required}
+                    """.format(
+                        name=self.name,
+                        required=self.required,
+                        description=self.description,
+                        input_type=self.input_type.value,
+                        input_format=self.input_format,
+                        default_value=self.default_value,
+                        enum=self.enum,
+                    ),
+                )
+            else:
+                parameter_entry = inspect.cleandoc(
+                    """
+                        - in: query
+                          name: {name}
+                          schema:
+                            type: {input_type}
+                            {input_format}
+                          {default_value}
+                          {description}
+                          required: {required}
+                    """.format(
+                        name=self.name,
+                        required=self.required,
+                        description=self.description,
+                        input_type=self.input_type.value,
+                        input_format=self.input_format,
+                        default_value=self.default_value,
+                    ),
+                )
 
         param = self.indent(parameter_entry, 3 * self.TAB)
         file.write(param)
@@ -484,6 +509,7 @@ class SwaggerPath(SwaggerModel):
                     swagger_request_type.add_swagger_model(parameters)
                 query_schema = query_model.schema()
                 query_required_fields = set(query_schema.get('required')) if query_schema.get('required') is not None else set()
+                query_definitions = query_schema.get('definitions')
                 for parameter_name, parameter_spec in query_schema.get('properties').items():
                     if parameter_spec.get('type') is not None:
                         parameter_models.add(SwaggerQueryParameter(
@@ -494,6 +520,17 @@ class SwaggerPath(SwaggerModel):
                             description=parameter_spec.get('description'),
                             required=parameter_name in query_required_fields,
                         ))
+                    elif parameter_spec.get('$ref') is not None:
+                        definition = query_definitions.get(parameter_spec.get('$ref', '').split('/')[-1], {})
+                        parameter_models.add(SwaggerQueryParameter(
+                            input_type=definition.get('type', 'string'),
+                            input_format=definition.get('format'),
+                            default_value=definition.get('default'),
+                            name=parameter_name,
+                            description=definition.get('description'),
+                            enum=definition.get('enum'),
+                            required=parameter_name in query_required_fields,
+                        ))
                 if isinstance(parameters, SwaggerModel):
                     parameters.add_swagger_models(parameter_models)
                 elif isinstance(parameters, list):
