@@ -1,5 +1,6 @@
 import dataclasses
 import decimal
+import json
 from base64 import b64encode
 from datetime import date, datetime
 from enum import Enum
@@ -98,3 +99,15 @@ class CustomJSONEncoder(JSONEncoder):
                         fields[field] = val
                 return fields
         return super().default(obj)
+
+
+class SocketIOJsonWrapper:
+    @staticmethod
+    def dumps(*args: Any, **kwargs: Any) -> str:
+        if 'cls' not in kwargs:
+            kwargs['cls'] = CustomJSONEncoder
+        return json.dumps(*args, **kwargs)
+
+    @staticmethod
+    def loads(*args: Any, **kwargs: Any) -> Any:
+        return json.loads(*args, **kwargs)
